import _plotly_utils.basevalidators


class StartlinecolorValidator(_plotly_utils.basevalidators.ColorValidator):
    def __init__(
        self, plotly_name="startlinecolor", parent_name="carpet.aaxis", **kwargs
    ):
        super(StartlinecolorValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            **kwargs
        )
